# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetStateConfigurationsResult',
    'AwaitableGetStateConfigurationsResult',
    'get_state_configurations',
    'get_state_configurations_output',
]

@pulumi.output_type
class GetStateConfigurationsResult:
    """
    A collection of values returned by getStateConfigurations.
    """
    def __init__(__self__, configurations=None, id=None, ids=None, output_file=None, resource_group_id=None, tags=None):
        if configurations and not isinstance(configurations, list):
            raise TypeError("Expected argument 'configurations' to be a list")
        pulumi.set(__self__, "configurations", configurations)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def configurations(self) -> Sequence['outputs.GetStateConfigurationsConfigurationResult']:
        return pulumi.get(self, "configurations")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[str]:
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, Any]]:
        return pulumi.get(self, "tags")


class AwaitableGetStateConfigurationsResult(GetStateConfigurationsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStateConfigurationsResult(
            configurations=self.configurations,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            resource_group_id=self.resource_group_id,
            tags=self.tags)


def get_state_configurations(ids: Optional[Sequence[str]] = None,
                             output_file: Optional[str] = None,
                             resource_group_id: Optional[str] = None,
                             tags: Optional[Mapping[str, Any]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStateConfigurationsResult:
    """
    This data source provides the Oos State Configurations of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.147.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.oos.get_state_configurations()
    pulumi.export("oosStateConfigurationId1", ids.configurations[0].id)
    ```


    :param Sequence[str] ids: A list of State Configuration IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The ID of the resource group.
    :param Mapping[str, Any] tags: The tag of the resource.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:oos/getStateConfigurations:getStateConfigurations', __args__, opts=opts, typ=GetStateConfigurationsResult).value

    return AwaitableGetStateConfigurationsResult(
        configurations=pulumi.get(__ret__, 'configurations'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        tags=pulumi.get(__ret__, 'tags'))


@_utilities.lift_output_func(get_state_configurations)
def get_state_configurations_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                    output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                    resource_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                                    tags: Optional[pulumi.Input[Optional[Mapping[str, Any]]]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetStateConfigurationsResult]:
    """
    This data source provides the Oos State Configurations of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.147.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.oos.get_state_configurations()
    pulumi.export("oosStateConfigurationId1", ids.configurations[0].id)
    ```


    :param Sequence[str] ids: A list of State Configuration IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The ID of the resource group.
    :param Mapping[str, Any] tags: The tag of the resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['VirtualPhysicalConnectionArgs', 'VirtualPhysicalConnection']

@pulumi.input_type
class VirtualPhysicalConnectionArgs:
    def __init__(__self__, *,
                 order_mode: pulumi.Input[str],
                 parent_physical_connection_id: pulumi.Input[str],
                 spec: pulumi.Input[str],
                 vlan_id: pulumi.Input[int],
                 vpconn_ali_uid: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 expect_spec: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 virtual_physical_connection_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a VirtualPhysicalConnection resource.
        :param pulumi.Input[str] order_mode: The payment method of shared dedicated line. Value:
               - **PayByPhysicalConnectionOwner**: indicates that the owner of the physical line associated with the shared line pays.
               - **PayByVirtualPhysicalConnectionOwner**: indicates that the owner of the shared line pays.
        :param pulumi.Input[str] parent_physical_connection_id: The ID of the instance of the physical connection.
        :param pulumi.Input[str] spec: The bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        :param pulumi.Input[int] vlan_id: The VLAN ID of the shared leased line. Valid values: `0` to `2999`.
        :param pulumi.Input[str] vpconn_ali_uid: The ID of the Alibaba Cloud account (primary account) of the owner of the shared line.
        :param pulumi.Input[str] description: The description of the physical connection.
        :param pulumi.Input[bool] dry_run: Specifies whether to precheck the API request. Valid values: `true` and `false`.
        :param pulumi.Input[str] expect_spec: The estimated bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        :param pulumi.Input[str] resource_group_id: The resource group id.
        :param pulumi.Input[str] virtual_physical_connection_name: The name of the physical connection.
        """
        pulumi.set(__self__, "order_mode", order_mode)
        pulumi.set(__self__, "parent_physical_connection_id", parent_physical_connection_id)
        pulumi.set(__self__, "spec", spec)
        pulumi.set(__self__, "vlan_id", vlan_id)
        pulumi.set(__self__, "vpconn_ali_uid", vpconn_ali_uid)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if expect_spec is not None:
            pulumi.set(__self__, "expect_spec", expect_spec)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if virtual_physical_connection_name is not None:
            pulumi.set(__self__, "virtual_physical_connection_name", virtual_physical_connection_name)

    @property
    @pulumi.getter(name="orderMode")
    def order_mode(self) -> pulumi.Input[str]:
        """
        The payment method of shared dedicated line. Value:
        - **PayByPhysicalConnectionOwner**: indicates that the owner of the physical line associated with the shared line pays.
        - **PayByVirtualPhysicalConnectionOwner**: indicates that the owner of the shared line pays.
        """
        return pulumi.get(self, "order_mode")

    @order_mode.setter
    def order_mode(self, value: pulumi.Input[str]):
        pulumi.set(self, "order_mode", value)

    @property
    @pulumi.getter(name="parentPhysicalConnectionId")
    def parent_physical_connection_id(self) -> pulumi.Input[str]:
        """
        The ID of the instance of the physical connection.
        """
        return pulumi.get(self, "parent_physical_connection_id")

    @parent_physical_connection_id.setter
    def parent_physical_connection_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "parent_physical_connection_id", value)

    @property
    @pulumi.getter
    def spec(self) -> pulumi.Input[str]:
        """
        The bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: pulumi.Input[str]):
        pulumi.set(self, "spec", value)

    @property
    @pulumi.getter(name="vlanId")
    def vlan_id(self) -> pulumi.Input[int]:
        """
        The VLAN ID of the shared leased line. Valid values: `0` to `2999`.
        """
        return pulumi.get(self, "vlan_id")

    @vlan_id.setter
    def vlan_id(self, value: pulumi.Input[int]):
        pulumi.set(self, "vlan_id", value)

    @property
    @pulumi.getter(name="vpconnAliUid")
    def vpconn_ali_uid(self) -> pulumi.Input[str]:
        """
        The ID of the Alibaba Cloud account (primary account) of the owner of the shared line.
        """
        return pulumi.get(self, "vpconn_ali_uid")

    @vpconn_ali_uid.setter
    def vpconn_ali_uid(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpconn_ali_uid", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the physical connection.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to precheck the API request. Valid values: `true` and `false`.
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="expectSpec")
    def expect_spec(self) -> Optional[pulumi.Input[str]]:
        """
        The estimated bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        """
        return pulumi.get(self, "expect_spec")

    @expect_spec.setter
    def expect_spec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expect_spec", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource group id.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter(name="virtualPhysicalConnectionName")
    def virtual_physical_connection_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the physical connection.
        """
        return pulumi.get(self, "virtual_physical_connection_name")

    @virtual_physical_connection_name.setter
    def virtual_physical_connection_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "virtual_physical_connection_name", value)


@pulumi.input_type
class _VirtualPhysicalConnectionState:
    def __init__(__self__, *,
                 access_point_id: Optional[pulumi.Input[str]] = None,
                 ad_location: Optional[pulumi.Input[str]] = None,
                 bandwidth: Optional[pulumi.Input[str]] = None,
                 business_status: Optional[pulumi.Input[str]] = None,
                 circuit_code: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 enabled_time: Optional[pulumi.Input[str]] = None,
                 end_time: Optional[pulumi.Input[str]] = None,
                 expect_spec: Optional[pulumi.Input[str]] = None,
                 line_operator: Optional[pulumi.Input[str]] = None,
                 loa_status: Optional[pulumi.Input[str]] = None,
                 order_mode: Optional[pulumi.Input[str]] = None,
                 parent_physical_connection_ali_uid: Optional[pulumi.Input[str]] = None,
                 parent_physical_connection_id: Optional[pulumi.Input[str]] = None,
                 peer_location: Optional[pulumi.Input[str]] = None,
                 port_number: Optional[pulumi.Input[str]] = None,
                 port_type: Optional[pulumi.Input[str]] = None,
                 redundant_physical_connection_id: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 spec: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 virtual_physical_connection_name: Optional[pulumi.Input[str]] = None,
                 virtual_physical_connection_status: Optional[pulumi.Input[str]] = None,
                 vlan_id: Optional[pulumi.Input[int]] = None,
                 vpconn_ali_uid: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering VirtualPhysicalConnection resources.
        :param pulumi.Input[str] access_point_id: The ID of the access point of the physical connection.
        :param pulumi.Input[str] ad_location: The physical location where the physical connection access device is located.
        :param pulumi.Input[str] bandwidth: The bandwidth of the physical connection. Unit: Mbps.
        :param pulumi.Input[str] business_status: The commercial status of the physical line. Value:-**Normal**: activated.-**Financialized**: Arrears locked.-**SecurityLocked**: locked for security reasons.
        :param pulumi.Input[str] circuit_code: The circuit code provided by the operator for the physical connection.
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] description: The description of the physical connection.
        :param pulumi.Input[bool] dry_run: Specifies whether to precheck the API request. Valid values: `true` and `false`.
        :param pulumi.Input[str] enabled_time: The opening time of the physical connection.
        :param pulumi.Input[str] end_time: The expiration time of the shared line.Time is expressed according to ISO8601 standard and UTC time is used. The format is: YYYY-MM-DDThh:mm:ssZ.
        :param pulumi.Input[str] expect_spec: The estimated bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        :param pulumi.Input[str] line_operator: Operators that provide access to physical lines. Value:-**CT**: China Telecom.-**CU**: China Unicom.-**CM**: China Mobile.-**CO**: China Other.-**Equinix**:Equinix.-**Other**: Other abroad.
        :param pulumi.Input[str] loa_status: The state of LOA. Value:-**Applying**:LOA application.-**Accept**:LOA application passed.-**Available**:LOA is Available.-**Rejected**:LOA application Rejected.-**Completing**: The dedicated line is under construction.-**Complete**: The construction of the dedicated line is completed.-**Deleted**:LOA has been Deleted.
        :param pulumi.Input[str] order_mode: The payment method of shared dedicated line. Value:
               - **PayByPhysicalConnectionOwner**: indicates that the owner of the physical line associated with the shared line pays.
               - **PayByVirtualPhysicalConnectionOwner**: indicates that the owner of the shared line pays.
        :param pulumi.Input[str] parent_physical_connection_ali_uid: The ID of the Alibaba Cloud account (primary account) to which the physical connection belongs.
        :param pulumi.Input[str] parent_physical_connection_id: The ID of the instance of the physical connection.
        :param pulumi.Input[str] peer_location: The geographic location of the local data center.
        :param pulumi.Input[str] port_number: The port number of the physical connection device.
        :param pulumi.Input[str] port_type: Physical connection port type. Value:-**100Base-T**: 100 megabytes port.-**1000Base-T**: Gigabit port.-**1000Base-LX**: Gigabit single mode optical port (10km).-**10GBase-T**: 10 Gigabit port.-**10GBase-LR**: 10 Gigabit single mode optical port (10km).-**40GBase-LR**: 40 megabytes single-mode optical port.-**100GBase-LR**: 100,000 megabytes single-mode optical port.
        :param pulumi.Input[str] redundant_physical_connection_id: The ID of the redundant physical connection.
        :param pulumi.Input[str] resource_group_id: The resource group id.
        :param pulumi.Input[str] spec: The bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        :param pulumi.Input[str] status: The status of the resource
        :param pulumi.Input[str] virtual_physical_connection_name: The name of the physical connection.
        :param pulumi.Input[str] virtual_physical_connection_status: The business status of the shared line. Value:-**Confirmed**: The shared line has been Confirmed to receive.-**UnConfirmed**: The shared line has not been confirmed to be received.-**Deleted**: The shared line has been Deleted.
        :param pulumi.Input[int] vlan_id: The VLAN ID of the shared leased line. Valid values: `0` to `2999`.
        :param pulumi.Input[str] vpconn_ali_uid: The ID of the Alibaba Cloud account (primary account) of the owner of the shared line.
        """
        if access_point_id is not None:
            pulumi.set(__self__, "access_point_id", access_point_id)
        if ad_location is not None:
            pulumi.set(__self__, "ad_location", ad_location)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if business_status is not None:
            pulumi.set(__self__, "business_status", business_status)
        if circuit_code is not None:
            pulumi.set(__self__, "circuit_code", circuit_code)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if enabled_time is not None:
            pulumi.set(__self__, "enabled_time", enabled_time)
        if end_time is not None:
            pulumi.set(__self__, "end_time", end_time)
        if expect_spec is not None:
            pulumi.set(__self__, "expect_spec", expect_spec)
        if line_operator is not None:
            pulumi.set(__self__, "line_operator", line_operator)
        if loa_status is not None:
            pulumi.set(__self__, "loa_status", loa_status)
        if order_mode is not None:
            pulumi.set(__self__, "order_mode", order_mode)
        if parent_physical_connection_ali_uid is not None:
            pulumi.set(__self__, "parent_physical_connection_ali_uid", parent_physical_connection_ali_uid)
        if parent_physical_connection_id is not None:
            pulumi.set(__self__, "parent_physical_connection_id", parent_physical_connection_id)
        if peer_location is not None:
            pulumi.set(__self__, "peer_location", peer_location)
        if port_number is not None:
            pulumi.set(__self__, "port_number", port_number)
        if port_type is not None:
            pulumi.set(__self__, "port_type", port_type)
        if redundant_physical_connection_id is not None:
            pulumi.set(__self__, "redundant_physical_connection_id", redundant_physical_connection_id)
        if resource_group_id is not None:
            pulumi.set(__self__, "resource_group_id", resource_group_id)
        if spec is not None:
            pulumi.set(__self__, "spec", spec)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if virtual_physical_connection_name is not None:
            pulumi.set(__self__, "virtual_physical_connection_name", virtual_physical_connection_name)
        if virtual_physical_connection_status is not None:
            pulumi.set(__self__, "virtual_physical_connection_status", virtual_physical_connection_status)
        if vlan_id is not None:
            pulumi.set(__self__, "vlan_id", vlan_id)
        if vpconn_ali_uid is not None:
            pulumi.set(__self__, "vpconn_ali_uid", vpconn_ali_uid)

    @property
    @pulumi.getter(name="accessPointId")
    def access_point_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the access point of the physical connection.
        """
        return pulumi.get(self, "access_point_id")

    @access_point_id.setter
    def access_point_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_point_id", value)

    @property
    @pulumi.getter(name="adLocation")
    def ad_location(self) -> Optional[pulumi.Input[str]]:
        """
        The physical location where the physical connection access device is located.
        """
        return pulumi.get(self, "ad_location")

    @ad_location.setter
    def ad_location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ad_location", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[str]]:
        """
        The bandwidth of the physical connection. Unit: Mbps.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[pulumi.Input[str]]:
        """
        The commercial status of the physical line. Value:-**Normal**: activated.-**Financialized**: Arrears locked.-**SecurityLocked**: locked for security reasons.
        """
        return pulumi.get(self, "business_status")

    @business_status.setter
    def business_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "business_status", value)

    @property
    @pulumi.getter(name="circuitCode")
    def circuit_code(self) -> Optional[pulumi.Input[str]]:
        """
        The circuit code provided by the operator for the physical connection.
        """
        return pulumi.get(self, "circuit_code")

    @circuit_code.setter
    def circuit_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "circuit_code", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the physical connection.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to precheck the API request. Valid values: `true` and `false`.
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="enabledTime")
    def enabled_time(self) -> Optional[pulumi.Input[str]]:
        """
        The opening time of the physical connection.
        """
        return pulumi.get(self, "enabled_time")

    @enabled_time.setter
    def enabled_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enabled_time", value)

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> Optional[pulumi.Input[str]]:
        """
        The expiration time of the shared line.Time is expressed according to ISO8601 standard and UTC time is used. The format is: YYYY-MM-DDThh:mm:ssZ.
        """
        return pulumi.get(self, "end_time")

    @end_time.setter
    def end_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "end_time", value)

    @property
    @pulumi.getter(name="expectSpec")
    def expect_spec(self) -> Optional[pulumi.Input[str]]:
        """
        The estimated bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        """
        return pulumi.get(self, "expect_spec")

    @expect_spec.setter
    def expect_spec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "expect_spec", value)

    @property
    @pulumi.getter(name="lineOperator")
    def line_operator(self) -> Optional[pulumi.Input[str]]:
        """
        Operators that provide access to physical lines. Value:-**CT**: China Telecom.-**CU**: China Unicom.-**CM**: China Mobile.-**CO**: China Other.-**Equinix**:Equinix.-**Other**: Other abroad.
        """
        return pulumi.get(self, "line_operator")

    @line_operator.setter
    def line_operator(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "line_operator", value)

    @property
    @pulumi.getter(name="loaStatus")
    def loa_status(self) -> Optional[pulumi.Input[str]]:
        """
        The state of LOA. Value:-**Applying**:LOA application.-**Accept**:LOA application passed.-**Available**:LOA is Available.-**Rejected**:LOA application Rejected.-**Completing**: The dedicated line is under construction.-**Complete**: The construction of the dedicated line is completed.-**Deleted**:LOA has been Deleted.
        """
        return pulumi.get(self, "loa_status")

    @loa_status.setter
    def loa_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "loa_status", value)

    @property
    @pulumi.getter(name="orderMode")
    def order_mode(self) -> Optional[pulumi.Input[str]]:
        """
        The payment method of shared dedicated line. Value:
        - **PayByPhysicalConnectionOwner**: indicates that the owner of the physical line associated with the shared line pays.
        - **PayByVirtualPhysicalConnectionOwner**: indicates that the owner of the shared line pays.
        """
        return pulumi.get(self, "order_mode")

    @order_mode.setter
    def order_mode(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "order_mode", value)

    @property
    @pulumi.getter(name="parentPhysicalConnectionAliUid")
    def parent_physical_connection_ali_uid(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Alibaba Cloud account (primary account) to which the physical connection belongs.
        """
        return pulumi.get(self, "parent_physical_connection_ali_uid")

    @parent_physical_connection_ali_uid.setter
    def parent_physical_connection_ali_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "parent_physical_connection_ali_uid", value)

    @property
    @pulumi.getter(name="parentPhysicalConnectionId")
    def parent_physical_connection_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the instance of the physical connection.
        """
        return pulumi.get(self, "parent_physical_connection_id")

    @parent_physical_connection_id.setter
    def parent_physical_connection_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "parent_physical_connection_id", value)

    @property
    @pulumi.getter(name="peerLocation")
    def peer_location(self) -> Optional[pulumi.Input[str]]:
        """
        The geographic location of the local data center.
        """
        return pulumi.get(self, "peer_location")

    @peer_location.setter
    def peer_location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peer_location", value)

    @property
    @pulumi.getter(name="portNumber")
    def port_number(self) -> Optional[pulumi.Input[str]]:
        """
        The port number of the physical connection device.
        """
        return pulumi.get(self, "port_number")

    @port_number.setter
    def port_number(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port_number", value)

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> Optional[pulumi.Input[str]]:
        """
        Physical connection port type. Value:-**100Base-T**: 100 megabytes port.-**1000Base-T**: Gigabit port.-**1000Base-LX**: Gigabit single mode optical port (10km).-**10GBase-T**: 10 Gigabit port.-**10GBase-LR**: 10 Gigabit single mode optical port (10km).-**40GBase-LR**: 40 megabytes single-mode optical port.-**100GBase-LR**: 100,000 megabytes single-mode optical port.
        """
        return pulumi.get(self, "port_type")

    @port_type.setter
    def port_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "port_type", value)

    @property
    @pulumi.getter(name="redundantPhysicalConnectionId")
    def redundant_physical_connection_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the redundant physical connection.
        """
        return pulumi.get(self, "redundant_physical_connection_id")

    @redundant_physical_connection_id.setter
    def redundant_physical_connection_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "redundant_physical_connection_id", value)

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The resource group id.
        """
        return pulumi.get(self, "resource_group_id")

    @resource_group_id.setter
    def resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_id", value)

    @property
    @pulumi.getter
    def spec(self) -> Optional[pulumi.Input[str]]:
        """
        The bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        """
        return pulumi.get(self, "spec")

    @spec.setter
    def spec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "spec", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="virtualPhysicalConnectionName")
    def virtual_physical_connection_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the physical connection.
        """
        return pulumi.get(self, "virtual_physical_connection_name")

    @virtual_physical_connection_name.setter
    def virtual_physical_connection_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "virtual_physical_connection_name", value)

    @property
    @pulumi.getter(name="virtualPhysicalConnectionStatus")
    def virtual_physical_connection_status(self) -> Optional[pulumi.Input[str]]:
        """
        The business status of the shared line. Value:-**Confirmed**: The shared line has been Confirmed to receive.-**UnConfirmed**: The shared line has not been confirmed to be received.-**Deleted**: The shared line has been Deleted.
        """
        return pulumi.get(self, "virtual_physical_connection_status")

    @virtual_physical_connection_status.setter
    def virtual_physical_connection_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "virtual_physical_connection_status", value)

    @property
    @pulumi.getter(name="vlanId")
    def vlan_id(self) -> Optional[pulumi.Input[int]]:
        """
        The VLAN ID of the shared leased line. Valid values: `0` to `2999`.
        """
        return pulumi.get(self, "vlan_id")

    @vlan_id.setter
    def vlan_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "vlan_id", value)

    @property
    @pulumi.getter(name="vpconnAliUid")
    def vpconn_ali_uid(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Alibaba Cloud account (primary account) of the owner of the shared line.
        """
        return pulumi.get(self, "vpconn_ali_uid")

    @vpconn_ali_uid.setter
    def vpconn_ali_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpconn_ali_uid", value)


class VirtualPhysicalConnection(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 expect_spec: Optional[pulumi.Input[str]] = None,
                 order_mode: Optional[pulumi.Input[str]] = None,
                 parent_physical_connection_id: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 spec: Optional[pulumi.Input[str]] = None,
                 virtual_physical_connection_name: Optional[pulumi.Input[str]] = None,
                 vlan_id: Optional[pulumi.Input[int]] = None,
                 vpconn_ali_uid: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Express Connect Virtual Physical Connection resource.

        For information about Express Connect Virtual Physical Connection and how to use it, see [What is Virtual Physical Connection](https://www.alibabacloud.com/help/en/express-connect/latest/createvirtualphysicalconnection#doc-api-Vpc-CreateVirtualPhysicalConnection).

        > **NOTE:** Available in v1.196.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_physical_connections = alicloud.expressconnect.get_physical_connections(name_regex="^preserved-NODELETING")
        default_virtual_physical_connection = alicloud.expressconnect.VirtualPhysicalConnection("defaultVirtualPhysicalConnection",
            virtual_physical_connection_name="amp_resource_test",
            description="amp_resource_test",
            order_mode="PayByPhysicalConnectionOwner",
            parent_physical_connection_id=default_physical_connections.ids[0],
            spec="50M",
            vlan_id=789,
            vpconn_ali_uid="1234567890")
        ```

        ## Import

        Express Connect Virtual Physical Connection can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:expressconnect/virtualPhysicalConnection:VirtualPhysicalConnection example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the physical connection.
        :param pulumi.Input[bool] dry_run: Specifies whether to precheck the API request. Valid values: `true` and `false`.
        :param pulumi.Input[str] expect_spec: The estimated bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        :param pulumi.Input[str] order_mode: The payment method of shared dedicated line. Value:
               - **PayByPhysicalConnectionOwner**: indicates that the owner of the physical line associated with the shared line pays.
               - **PayByVirtualPhysicalConnectionOwner**: indicates that the owner of the shared line pays.
        :param pulumi.Input[str] parent_physical_connection_id: The ID of the instance of the physical connection.
        :param pulumi.Input[str] resource_group_id: The resource group id.
        :param pulumi.Input[str] spec: The bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        :param pulumi.Input[str] virtual_physical_connection_name: The name of the physical connection.
        :param pulumi.Input[int] vlan_id: The VLAN ID of the shared leased line. Valid values: `0` to `2999`.
        :param pulumi.Input[str] vpconn_ali_uid: The ID of the Alibaba Cloud account (primary account) of the owner of the shared line.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VirtualPhysicalConnectionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Express Connect Virtual Physical Connection resource.

        For information about Express Connect Virtual Physical Connection and how to use it, see [What is Virtual Physical Connection](https://www.alibabacloud.com/help/en/express-connect/latest/createvirtualphysicalconnection#doc-api-Vpc-CreateVirtualPhysicalConnection).

        > **NOTE:** Available in v1.196.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default_physical_connections = alicloud.expressconnect.get_physical_connections(name_regex="^preserved-NODELETING")
        default_virtual_physical_connection = alicloud.expressconnect.VirtualPhysicalConnection("defaultVirtualPhysicalConnection",
            virtual_physical_connection_name="amp_resource_test",
            description="amp_resource_test",
            order_mode="PayByPhysicalConnectionOwner",
            parent_physical_connection_id=default_physical_connections.ids[0],
            spec="50M",
            vlan_id=789,
            vpconn_ali_uid="1234567890")
        ```

        ## Import

        Express Connect Virtual Physical Connection can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:expressconnect/virtualPhysicalConnection:VirtualPhysicalConnection example <id>
        ```

        :param str resource_name: The name of the resource.
        :param VirtualPhysicalConnectionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VirtualPhysicalConnectionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 expect_spec: Optional[pulumi.Input[str]] = None,
                 order_mode: Optional[pulumi.Input[str]] = None,
                 parent_physical_connection_id: Optional[pulumi.Input[str]] = None,
                 resource_group_id: Optional[pulumi.Input[str]] = None,
                 spec: Optional[pulumi.Input[str]] = None,
                 virtual_physical_connection_name: Optional[pulumi.Input[str]] = None,
                 vlan_id: Optional[pulumi.Input[int]] = None,
                 vpconn_ali_uid: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VirtualPhysicalConnectionArgs.__new__(VirtualPhysicalConnectionArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["dry_run"] = dry_run
            __props__.__dict__["expect_spec"] = expect_spec
            if order_mode is None and not opts.urn:
                raise TypeError("Missing required property 'order_mode'")
            __props__.__dict__["order_mode"] = order_mode
            if parent_physical_connection_id is None and not opts.urn:
                raise TypeError("Missing required property 'parent_physical_connection_id'")
            __props__.__dict__["parent_physical_connection_id"] = parent_physical_connection_id
            __props__.__dict__["resource_group_id"] = resource_group_id
            if spec is None and not opts.urn:
                raise TypeError("Missing required property 'spec'")
            __props__.__dict__["spec"] = spec
            __props__.__dict__["virtual_physical_connection_name"] = virtual_physical_connection_name
            if vlan_id is None and not opts.urn:
                raise TypeError("Missing required property 'vlan_id'")
            __props__.__dict__["vlan_id"] = vlan_id
            if vpconn_ali_uid is None and not opts.urn:
                raise TypeError("Missing required property 'vpconn_ali_uid'")
            __props__.__dict__["vpconn_ali_uid"] = vpconn_ali_uid
            __props__.__dict__["access_point_id"] = None
            __props__.__dict__["ad_location"] = None
            __props__.__dict__["bandwidth"] = None
            __props__.__dict__["business_status"] = None
            __props__.__dict__["circuit_code"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["enabled_time"] = None
            __props__.__dict__["end_time"] = None
            __props__.__dict__["line_operator"] = None
            __props__.__dict__["loa_status"] = None
            __props__.__dict__["parent_physical_connection_ali_uid"] = None
            __props__.__dict__["peer_location"] = None
            __props__.__dict__["port_number"] = None
            __props__.__dict__["port_type"] = None
            __props__.__dict__["redundant_physical_connection_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["virtual_physical_connection_status"] = None
        super(VirtualPhysicalConnection, __self__).__init__(
            'alicloud:expressconnect/virtualPhysicalConnection:VirtualPhysicalConnection',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_point_id: Optional[pulumi.Input[str]] = None,
            ad_location: Optional[pulumi.Input[str]] = None,
            bandwidth: Optional[pulumi.Input[str]] = None,
            business_status: Optional[pulumi.Input[str]] = None,
            circuit_code: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            dry_run: Optional[pulumi.Input[bool]] = None,
            enabled_time: Optional[pulumi.Input[str]] = None,
            end_time: Optional[pulumi.Input[str]] = None,
            expect_spec: Optional[pulumi.Input[str]] = None,
            line_operator: Optional[pulumi.Input[str]] = None,
            loa_status: Optional[pulumi.Input[str]] = None,
            order_mode: Optional[pulumi.Input[str]] = None,
            parent_physical_connection_ali_uid: Optional[pulumi.Input[str]] = None,
            parent_physical_connection_id: Optional[pulumi.Input[str]] = None,
            peer_location: Optional[pulumi.Input[str]] = None,
            port_number: Optional[pulumi.Input[str]] = None,
            port_type: Optional[pulumi.Input[str]] = None,
            redundant_physical_connection_id: Optional[pulumi.Input[str]] = None,
            resource_group_id: Optional[pulumi.Input[str]] = None,
            spec: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            virtual_physical_connection_name: Optional[pulumi.Input[str]] = None,
            virtual_physical_connection_status: Optional[pulumi.Input[str]] = None,
            vlan_id: Optional[pulumi.Input[int]] = None,
            vpconn_ali_uid: Optional[pulumi.Input[str]] = None) -> 'VirtualPhysicalConnection':
        """
        Get an existing VirtualPhysicalConnection resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_point_id: The ID of the access point of the physical connection.
        :param pulumi.Input[str] ad_location: The physical location where the physical connection access device is located.
        :param pulumi.Input[str] bandwidth: The bandwidth of the physical connection. Unit: Mbps.
        :param pulumi.Input[str] business_status: The commercial status of the physical line. Value:-**Normal**: activated.-**Financialized**: Arrears locked.-**SecurityLocked**: locked for security reasons.
        :param pulumi.Input[str] circuit_code: The circuit code provided by the operator for the physical connection.
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] description: The description of the physical connection.
        :param pulumi.Input[bool] dry_run: Specifies whether to precheck the API request. Valid values: `true` and `false`.
        :param pulumi.Input[str] enabled_time: The opening time of the physical connection.
        :param pulumi.Input[str] end_time: The expiration time of the shared line.Time is expressed according to ISO8601 standard and UTC time is used. The format is: YYYY-MM-DDThh:mm:ssZ.
        :param pulumi.Input[str] expect_spec: The estimated bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        :param pulumi.Input[str] line_operator: Operators that provide access to physical lines. Value:-**CT**: China Telecom.-**CU**: China Unicom.-**CM**: China Mobile.-**CO**: China Other.-**Equinix**:Equinix.-**Other**: Other abroad.
        :param pulumi.Input[str] loa_status: The state of LOA. Value:-**Applying**:LOA application.-**Accept**:LOA application passed.-**Available**:LOA is Available.-**Rejected**:LOA application Rejected.-**Completing**: The dedicated line is under construction.-**Complete**: The construction of the dedicated line is completed.-**Deleted**:LOA has been Deleted.
        :param pulumi.Input[str] order_mode: The payment method of shared dedicated line. Value:
               - **PayByPhysicalConnectionOwner**: indicates that the owner of the physical line associated with the shared line pays.
               - **PayByVirtualPhysicalConnectionOwner**: indicates that the owner of the shared line pays.
        :param pulumi.Input[str] parent_physical_connection_ali_uid: The ID of the Alibaba Cloud account (primary account) to which the physical connection belongs.
        :param pulumi.Input[str] parent_physical_connection_id: The ID of the instance of the physical connection.
        :param pulumi.Input[str] peer_location: The geographic location of the local data center.
        :param pulumi.Input[str] port_number: The port number of the physical connection device.
        :param pulumi.Input[str] port_type: Physical connection port type. Value:-**100Base-T**: 100 megabytes port.-**1000Base-T**: Gigabit port.-**1000Base-LX**: Gigabit single mode optical port (10km).-**10GBase-T**: 10 Gigabit port.-**10GBase-LR**: 10 Gigabit single mode optical port (10km).-**40GBase-LR**: 40 megabytes single-mode optical port.-**100GBase-LR**: 100,000 megabytes single-mode optical port.
        :param pulumi.Input[str] redundant_physical_connection_id: The ID of the redundant physical connection.
        :param pulumi.Input[str] resource_group_id: The resource group id.
        :param pulumi.Input[str] spec: The bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        :param pulumi.Input[str] status: The status of the resource
        :param pulumi.Input[str] virtual_physical_connection_name: The name of the physical connection.
        :param pulumi.Input[str] virtual_physical_connection_status: The business status of the shared line. Value:-**Confirmed**: The shared line has been Confirmed to receive.-**UnConfirmed**: The shared line has not been confirmed to be received.-**Deleted**: The shared line has been Deleted.
        :param pulumi.Input[int] vlan_id: The VLAN ID of the shared leased line. Valid values: `0` to `2999`.
        :param pulumi.Input[str] vpconn_ali_uid: The ID of the Alibaba Cloud account (primary account) of the owner of the shared line.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VirtualPhysicalConnectionState.__new__(_VirtualPhysicalConnectionState)

        __props__.__dict__["access_point_id"] = access_point_id
        __props__.__dict__["ad_location"] = ad_location
        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["business_status"] = business_status
        __props__.__dict__["circuit_code"] = circuit_code
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["dry_run"] = dry_run
        __props__.__dict__["enabled_time"] = enabled_time
        __props__.__dict__["end_time"] = end_time
        __props__.__dict__["expect_spec"] = expect_spec
        __props__.__dict__["line_operator"] = line_operator
        __props__.__dict__["loa_status"] = loa_status
        __props__.__dict__["order_mode"] = order_mode
        __props__.__dict__["parent_physical_connection_ali_uid"] = parent_physical_connection_ali_uid
        __props__.__dict__["parent_physical_connection_id"] = parent_physical_connection_id
        __props__.__dict__["peer_location"] = peer_location
        __props__.__dict__["port_number"] = port_number
        __props__.__dict__["port_type"] = port_type
        __props__.__dict__["redundant_physical_connection_id"] = redundant_physical_connection_id
        __props__.__dict__["resource_group_id"] = resource_group_id
        __props__.__dict__["spec"] = spec
        __props__.__dict__["status"] = status
        __props__.__dict__["virtual_physical_connection_name"] = virtual_physical_connection_name
        __props__.__dict__["virtual_physical_connection_status"] = virtual_physical_connection_status
        __props__.__dict__["vlan_id"] = vlan_id
        __props__.__dict__["vpconn_ali_uid"] = vpconn_ali_uid
        return VirtualPhysicalConnection(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accessPointId")
    def access_point_id(self) -> pulumi.Output[str]:
        """
        The ID of the access point of the physical connection.
        """
        return pulumi.get(self, "access_point_id")

    @property
    @pulumi.getter(name="adLocation")
    def ad_location(self) -> pulumi.Output[str]:
        """
        The physical location where the physical connection access device is located.
        """
        return pulumi.get(self, "ad_location")

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[str]:
        """
        The bandwidth of the physical connection. Unit: Mbps.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> pulumi.Output[str]:
        """
        The commercial status of the physical line. Value:-**Normal**: activated.-**Financialized**: Arrears locked.-**SecurityLocked**: locked for security reasons.
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="circuitCode")
    def circuit_code(self) -> pulumi.Output[str]:
        """
        The circuit code provided by the operator for the physical connection.
        """
        return pulumi.get(self, "circuit_code")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the physical connection.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether to precheck the API request. Valid values: `true` and `false`.
        """
        return pulumi.get(self, "dry_run")

    @property
    @pulumi.getter(name="enabledTime")
    def enabled_time(self) -> pulumi.Output[str]:
        """
        The opening time of the physical connection.
        """
        return pulumi.get(self, "enabled_time")

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> pulumi.Output[str]:
        """
        The expiration time of the shared line.Time is expressed according to ISO8601 standard and UTC time is used. The format is: YYYY-MM-DDThh:mm:ssZ.
        """
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter(name="expectSpec")
    def expect_spec(self) -> pulumi.Output[Optional[str]]:
        """
        The estimated bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        """
        return pulumi.get(self, "expect_spec")

    @property
    @pulumi.getter(name="lineOperator")
    def line_operator(self) -> pulumi.Output[str]:
        """
        Operators that provide access to physical lines. Value:-**CT**: China Telecom.-**CU**: China Unicom.-**CM**: China Mobile.-**CO**: China Other.-**Equinix**:Equinix.-**Other**: Other abroad.
        """
        return pulumi.get(self, "line_operator")

    @property
    @pulumi.getter(name="loaStatus")
    def loa_status(self) -> pulumi.Output[str]:
        """
        The state of LOA. Value:-**Applying**:LOA application.-**Accept**:LOA application passed.-**Available**:LOA is Available.-**Rejected**:LOA application Rejected.-**Completing**: The dedicated line is under construction.-**Complete**: The construction of the dedicated line is completed.-**Deleted**:LOA has been Deleted.
        """
        return pulumi.get(self, "loa_status")

    @property
    @pulumi.getter(name="orderMode")
    def order_mode(self) -> pulumi.Output[str]:
        """
        The payment method of shared dedicated line. Value:
        - **PayByPhysicalConnectionOwner**: indicates that the owner of the physical line associated with the shared line pays.
        - **PayByVirtualPhysicalConnectionOwner**: indicates that the owner of the shared line pays.
        """
        return pulumi.get(self, "order_mode")

    @property
    @pulumi.getter(name="parentPhysicalConnectionAliUid")
    def parent_physical_connection_ali_uid(self) -> pulumi.Output[str]:
        """
        The ID of the Alibaba Cloud account (primary account) to which the physical connection belongs.
        """
        return pulumi.get(self, "parent_physical_connection_ali_uid")

    @property
    @pulumi.getter(name="parentPhysicalConnectionId")
    def parent_physical_connection_id(self) -> pulumi.Output[str]:
        """
        The ID of the instance of the physical connection.
        """
        return pulumi.get(self, "parent_physical_connection_id")

    @property
    @pulumi.getter(name="peerLocation")
    def peer_location(self) -> pulumi.Output[str]:
        """
        The geographic location of the local data center.
        """
        return pulumi.get(self, "peer_location")

    @property
    @pulumi.getter(name="portNumber")
    def port_number(self) -> pulumi.Output[str]:
        """
        The port number of the physical connection device.
        """
        return pulumi.get(self, "port_number")

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> pulumi.Output[str]:
        """
        Physical connection port type. Value:-**100Base-T**: 100 megabytes port.-**1000Base-T**: Gigabit port.-**1000Base-LX**: Gigabit single mode optical port (10km).-**10GBase-T**: 10 Gigabit port.-**10GBase-LR**: 10 Gigabit single mode optical port (10km).-**40GBase-LR**: 40 megabytes single-mode optical port.-**100GBase-LR**: 100,000 megabytes single-mode optical port.
        """
        return pulumi.get(self, "port_type")

    @property
    @pulumi.getter(name="redundantPhysicalConnectionId")
    def redundant_physical_connection_id(self) -> pulumi.Output[str]:
        """
        The ID of the redundant physical connection.
        """
        return pulumi.get(self, "redundant_physical_connection_id")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> pulumi.Output[str]:
        """
        The resource group id.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def spec(self) -> pulumi.Output[str]:
        """
        The bandwidth value of the shared line. Valid values: `50M`, `100M`, `200M`, `300M`, `400M`, `500M`, `1G`, `2G`, `5G`, `8G`, and `10G`. **Note**: By default, the values of 2G, 5G, 8G, and 10G are unavailable. If you want to specify these values, contact your customer manager. Unit: **M** indicates Mbps, **G** indicates Gbps.
        """
        return pulumi.get(self, "spec")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="virtualPhysicalConnectionName")
    def virtual_physical_connection_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of the physical connection.
        """
        return pulumi.get(self, "virtual_physical_connection_name")

    @property
    @pulumi.getter(name="virtualPhysicalConnectionStatus")
    def virtual_physical_connection_status(self) -> pulumi.Output[str]:
        """
        The business status of the shared line. Value:-**Confirmed**: The shared line has been Confirmed to receive.-**UnConfirmed**: The shared line has not been confirmed to be received.-**Deleted**: The shared line has been Deleted.
        """
        return pulumi.get(self, "virtual_physical_connection_status")

    @property
    @pulumi.getter(name="vlanId")
    def vlan_id(self) -> pulumi.Output[int]:
        """
        The VLAN ID of the shared leased line. Valid values: `0` to `2999`.
        """
        return pulumi.get(self, "vlan_id")

    @property
    @pulumi.getter(name="vpconnAliUid")
    def vpconn_ali_uid(self) -> pulumi.Output[str]:
        """
        The ID of the Alibaba Cloud account (primary account) of the owner of the shared line.
        """
        return pulumi.get(self, "vpconn_ali_uid")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetAccessPointsPointResult',
    'GetAccessPointsPointAccessPointFeatureModelResult',
    'GetGrantRuleToCensCenResult',
    'GetPhysicalConnectionsConnectionResult',
    'GetRouterInterfacesFilterResult',
    'GetRouterInterfacesInterfaceResult',
    'GetVbrPconnAssociationsAssociationResult',
    'GetVirtualBorderRoutersFilterResult',
    'GetVirtualBorderRoutersRouterResult',
    'GetVirtualPhysicalConnectionsConnectionResult',
]

@pulumi.output_type
class GetAccessPointsPointResult(dict):
    def __init__(__self__, *,
                 access_point_feature_models: Sequence['outputs.GetAccessPointsPointAccessPointFeatureModelResult'],
                 access_point_id: str,
                 access_point_name: str,
                 attached_region_no: str,
                 description: str,
                 host_operator: str,
                 id: str,
                 location: str,
                 status: str,
                 type: str):
        """
        :param Sequence['GetAccessPointsPointAccessPointFeatureModelArgs'] access_point_feature_models: Query to the Access Point Feature Model.
        :param str access_point_id: The Access Point ID.
        :param str access_point_name: Access Point Name.
        :param str attached_region_no: The Access Point Is Located an ID.
        :param str description: The Access Point Description.
        :param str host_operator: The Access Point Belongs to the Operator.
        :param str id: The ID of the Access Point.
        :param str location: The Location of the Access Point.
        :param str status: The Physical Connection to Which the Access Point State.
        :param str type: The Physical Connection to Which the Network Type.
        """
        pulumi.set(__self__, "access_point_feature_models", access_point_feature_models)
        pulumi.set(__self__, "access_point_id", access_point_id)
        pulumi.set(__self__, "access_point_name", access_point_name)
        pulumi.set(__self__, "attached_region_no", attached_region_no)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "host_operator", host_operator)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "location", location)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="accessPointFeatureModels")
    def access_point_feature_models(self) -> Sequence['outputs.GetAccessPointsPointAccessPointFeatureModelResult']:
        """
        Query to the Access Point Feature Model.
        """
        return pulumi.get(self, "access_point_feature_models")

    @property
    @pulumi.getter(name="accessPointId")
    def access_point_id(self) -> str:
        """
        The Access Point ID.
        """
        return pulumi.get(self, "access_point_id")

    @property
    @pulumi.getter(name="accessPointName")
    def access_point_name(self) -> str:
        """
        Access Point Name.
        """
        return pulumi.get(self, "access_point_name")

    @property
    @pulumi.getter(name="attachedRegionNo")
    def attached_region_no(self) -> str:
        """
        The Access Point Is Located an ID.
        """
        return pulumi.get(self, "attached_region_no")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The Access Point Description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="hostOperator")
    def host_operator(self) -> str:
        """
        The Access Point Belongs to the Operator.
        """
        return pulumi.get(self, "host_operator")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Access Point.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def location(self) -> str:
        """
        The Location of the Access Point.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The Physical Connection to Which the Access Point State.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The Physical Connection to Which the Network Type.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetAccessPointsPointAccessPointFeatureModelResult(dict):
    def __init__(__self__, *,
                 feature_key: str,
                 feature_value: str):
        """
        :param str feature_key: The Access Point Properties.
        :param str feature_value: The Access Point Characteristic Value.
        """
        pulumi.set(__self__, "feature_key", feature_key)
        pulumi.set(__self__, "feature_value", feature_value)

    @property
    @pulumi.getter(name="featureKey")
    def feature_key(self) -> str:
        """
        The Access Point Properties.
        """
        return pulumi.get(self, "feature_key")

    @property
    @pulumi.getter(name="featureValue")
    def feature_value(self) -> str:
        """
        The Access Point Characteristic Value.
        """
        return pulumi.get(self, "feature_value")


@pulumi.output_type
class GetGrantRuleToCensCenResult(dict):
    def __init__(__self__, *,
                 cen_id: str,
                 cen_owner_id: int,
                 create_time: str,
                 id: str):
        """
        :param str cen_id: The ID of the authorized CEN instance.
        :param int cen_owner_id: The user ID (UID) of the Alibaba Cloud account to which the CEN instance belongs.
        :param str create_time: The time when the instance was created.
        :param str id: The ID of the Grant Rule To Cen. It formats as `<cen_id>:<cen_owner_id>:<instance_id>`.
        """
        pulumi.set(__self__, "cen_id", cen_id)
        pulumi.set(__self__, "cen_owner_id", cen_owner_id)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="cenId")
    def cen_id(self) -> str:
        """
        The ID of the authorized CEN instance.
        """
        return pulumi.get(self, "cen_id")

    @property
    @pulumi.getter(name="cenOwnerId")
    def cen_owner_id(self) -> int:
        """
        The user ID (UID) of the Alibaba Cloud account to which the CEN instance belongs.
        """
        return pulumi.get(self, "cen_owner_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The time when the instance was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Grant Rule To Cen. It formats as `<cen_id>:<cen_owner_id>:<instance_id>`.
        """
        return pulumi.get(self, "id")


@pulumi.output_type
class GetPhysicalConnectionsConnectionResult(dict):
    def __init__(__self__, *,
                 access_point_id: str,
                 ad_location: str,
                 bandwidth: str,
                 business_status: str,
                 circuit_code: str,
                 create_time: str,
                 description: str,
                 enabled_time: str,
                 end_time: str,
                 has_reservation_data: str,
                 id: str,
                 line_operator: str,
                 loa_status: str,
                 payment_type: str,
                 peer_location: str,
                 physical_connection_id: str,
                 physical_connection_name: str,
                 port_number: str,
                 port_type: str,
                 redundant_physical_connection_id: str,
                 reservation_active_time: str,
                 reservation_internet_charge_type: str,
                 reservation_order_type: str,
                 spec: str,
                 status: str,
                 type: str):
        """
        :param str access_point_id: The Physical Leased Line Access Point ID.
        :param str ad_location: To Connect a Device Physical Location.
        :param str bandwidth: On the Bandwidth of the ECC Service and Physical Connection.
        :param str business_status: The Physical Connection to Which the Payment Status: Normal, financiallocked, securitylocked.
        :param str circuit_code: Operators for Physical Connection Circuit Provided Coding.
        :param str create_time: The Representative of the Creation Time Resources Attribute Field.
        :param str description: The Physical Connection to Which the Description.
        :param str enabled_time: The Physical Connection to Which the Activation Time.
        :param str end_time: The Expiration Time.
        :param str has_reservation_data: HasReservationData.
        :param str id: The ID of the Physical Connection.
        :param str line_operator: Provides Access to the Physical Line Operator Value CT: China Telecom, CU: China Unicom, CM: china Mobile, CO: Other Chinese, Equinix:Equinix, Other: Other Overseas.
        :param str loa_status: Loa State.
        :param str payment_type: on Behalf of the Pay-as-You-Type of Resource Attribute Field.
        :param str peer_location: and an on-Premises Data Center Location.
        :param str physical_connection_id: on Behalf of the Resource Level Id of the Resources Property Fields.
        :param str physical_connection_name: on Behalf of the Resource Name of the Resources-Attribute Field.
        :param str port_number: To Connect a Device Port: The Port Number of.
        :param str port_type: The Physical Leased Line Access Port Type Value 100Base-T: Fast Electrical Ports, 1000Base-T (the Default): gigabit Electrical Ports, 1000Base-LX: Gigabit Singlemode Optical Ports (10Km), 10GBase-T: Gigabit Electrical Port, 10GBase-LR: Gigabit Singlemode Optical Ports (10Km).
        :param str redundant_physical_connection_id: Redundant Physical Connection to Which the ID.
        :param str reservation_active_time: The Renewal of the Entry into Force of the Time.
        :param str reservation_internet_charge_type: Renewal Type.
        :param str reservation_order_type: Renewal Order Type.
        :param str spec: The Physical Connection to Which the Specifications.
        :param str status: Resources on Behalf of a State of the Resource Attribute Field.
        :param str type: Physical Private Line of Type. Default Value: VPC.
        """
        pulumi.set(__self__, "access_point_id", access_point_id)
        pulumi.set(__self__, "ad_location", ad_location)
        pulumi.set(__self__, "bandwidth", bandwidth)
        pulumi.set(__self__, "business_status", business_status)
        pulumi.set(__self__, "circuit_code", circuit_code)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "enabled_time", enabled_time)
        pulumi.set(__self__, "end_time", end_time)
        pulumi.set(__self__, "has_reservation_data", has_reservation_data)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "line_operator", line_operator)
        pulumi.set(__self__, "loa_status", loa_status)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "peer_location", peer_location)
        pulumi.set(__self__, "physical_connection_id", physical_connection_id)
        pulumi.set(__self__, "physical_connection_name", physical_connection_name)
        pulumi.set(__self__, "port_number", port_number)
        pulumi.set(__self__, "port_type", port_type)
        pulumi.set(__self__, "redundant_physical_connection_id", redundant_physical_connection_id)
        pulumi.set(__self__, "reservation_active_time", reservation_active_time)
        pulumi.set(__self__, "reservation_internet_charge_type", reservation_internet_charge_type)
        pulumi.set(__self__, "reservation_order_type", reservation_order_type)
        pulumi.set(__self__, "spec", spec)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="accessPointId")
    def access_point_id(self) -> str:
        """
        The Physical Leased Line Access Point ID.
        """
        return pulumi.get(self, "access_point_id")

    @property
    @pulumi.getter(name="adLocation")
    def ad_location(self) -> str:
        """
        To Connect a Device Physical Location.
        """
        return pulumi.get(self, "ad_location")

    @property
    @pulumi.getter
    def bandwidth(self) -> str:
        """
        On the Bandwidth of the ECC Service and Physical Connection.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> str:
        """
        The Physical Connection to Which the Payment Status: Normal, financiallocked, securitylocked.
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="circuitCode")
    def circuit_code(self) -> str:
        """
        Operators for Physical Connection Circuit Provided Coding.
        """
        return pulumi.get(self, "circuit_code")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The Representative of the Creation Time Resources Attribute Field.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The Physical Connection to Which the Description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enabledTime")
    def enabled_time(self) -> str:
        """
        The Physical Connection to Which the Activation Time.
        """
        return pulumi.get(self, "enabled_time")

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> str:
        """
        The Expiration Time.
        """
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter(name="hasReservationData")
    def has_reservation_data(self) -> str:
        """
        HasReservationData.
        """
        return pulumi.get(self, "has_reservation_data")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Physical Connection.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lineOperator")
    def line_operator(self) -> str:
        """
        Provides Access to the Physical Line Operator Value CT: China Telecom, CU: China Unicom, CM: china Mobile, CO: Other Chinese, Equinix:Equinix, Other: Other Overseas.
        """
        return pulumi.get(self, "line_operator")

    @property
    @pulumi.getter(name="loaStatus")
    def loa_status(self) -> str:
        """
        Loa State.
        """
        return pulumi.get(self, "loa_status")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> str:
        """
        on Behalf of the Pay-as-You-Type of Resource Attribute Field.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="peerLocation")
    def peer_location(self) -> str:
        """
        and an on-Premises Data Center Location.
        """
        return pulumi.get(self, "peer_location")

    @property
    @pulumi.getter(name="physicalConnectionId")
    def physical_connection_id(self) -> str:
        """
        on Behalf of the Resource Level Id of the Resources Property Fields.
        """
        return pulumi.get(self, "physical_connection_id")

    @property
    @pulumi.getter(name="physicalConnectionName")
    def physical_connection_name(self) -> str:
        """
        on Behalf of the Resource Name of the Resources-Attribute Field.
        """
        return pulumi.get(self, "physical_connection_name")

    @property
    @pulumi.getter(name="portNumber")
    def port_number(self) -> str:
        """
        To Connect a Device Port: The Port Number of.
        """
        return pulumi.get(self, "port_number")

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> str:
        """
        The Physical Leased Line Access Port Type Value 100Base-T: Fast Electrical Ports, 1000Base-T (the Default): gigabit Electrical Ports, 1000Base-LX: Gigabit Singlemode Optical Ports (10Km), 10GBase-T: Gigabit Electrical Port, 10GBase-LR: Gigabit Singlemode Optical Ports (10Km).
        """
        return pulumi.get(self, "port_type")

    @property
    @pulumi.getter(name="redundantPhysicalConnectionId")
    def redundant_physical_connection_id(self) -> str:
        """
        Redundant Physical Connection to Which the ID.
        """
        return pulumi.get(self, "redundant_physical_connection_id")

    @property
    @pulumi.getter(name="reservationActiveTime")
    def reservation_active_time(self) -> str:
        """
        The Renewal of the Entry into Force of the Time.
        """
        return pulumi.get(self, "reservation_active_time")

    @property
    @pulumi.getter(name="reservationInternetChargeType")
    def reservation_internet_charge_type(self) -> str:
        """
        Renewal Type.
        """
        return pulumi.get(self, "reservation_internet_charge_type")

    @property
    @pulumi.getter(name="reservationOrderType")
    def reservation_order_type(self) -> str:
        """
        Renewal Order Type.
        """
        return pulumi.get(self, "reservation_order_type")

    @property
    @pulumi.getter
    def spec(self) -> str:
        """
        The Physical Connection to Which the Specifications.
        """
        return pulumi.get(self, "spec")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Resources on Behalf of a State of the Resource Attribute Field.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Physical Private Line of Type. Default Value: VPC.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetRouterInterfacesFilterResult(dict):
    def __init__(__self__, *,
                 key: Optional[str] = None,
                 values: Optional[Sequence[str]] = None):
        if key is not None:
            pulumi.set(__self__, "key", key)
        if values is not None:
            pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def values(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "values")


@pulumi.output_type
class GetRouterInterfacesInterfaceResult(dict):
    def __init__(__self__, *,
                 access_point_id: str,
                 bandwidth: int,
                 business_status: str,
                 connected_time: str,
                 create_time: str,
                 cross_border: bool,
                 description: str,
                 end_time: str,
                 has_reservation_data: str,
                 hc_rate: int,
                 hc_threshold: str,
                 health_check_source_ip: str,
                 health_check_target_ip: str,
                 id: str,
                 opposite_access_point_id: str,
                 opposite_bandwidth: int,
                 opposite_interface_business_status: str,
                 opposite_interface_id: str,
                 opposite_interface_owner_id: str,
                 opposite_interface_spec: str,
                 opposite_interface_status: str,
                 opposite_region_id: str,
                 opposite_router_id: str,
                 opposite_router_type: str,
                 opposite_vpc_instance_id: str,
                 payment_type: str,
                 reservation_active_time: str,
                 reservation_bandwidth: str,
                 reservation_internet_charge_type: str,
                 reservation_order_type: str,
                 role: str,
                 router_id: str,
                 router_interface_id: str,
                 router_interface_name: str,
                 router_type: str,
                 spec: str,
                 status: str,
                 vpc_instance_id: str):
        """
        :param str access_point_id: The access point ID to which the VBR belongs.
        :param int bandwidth: The bandwidth of the resource.
        :param str business_status: The businessStatus of the resource. Valid Values: `Normal`, `FinancialLocked`, `SecurityLocked`.
        :param str connected_time: The connected time of the resource.
        :param str create_time: The creation time of the resource
        :param bool cross_border: The cross border of the resource.
        :param str description: The description of the router interface.
        :param str end_time: The end time of the resource.
        :param str has_reservation_data: The has reservation data of the resource.
        :param int hc_rate: The hc rate of the resource.
        :param str hc_threshold: The hc threshold of the resource.
        :param str health_check_source_ip: The health check source IP address, must be an unused IP within the local VPC.
        :param str health_check_target_ip: The IP address for health screening purposes.
        :param str opposite_access_point_id: The Access point ID to which the other end belongs.
        :param int opposite_bandwidth: The opposite bandwidth of the router on the other side.
        :param str opposite_interface_business_status: The opposite interface business status of the router on the other side. Valid Values: `Normal`, `FinancialLocked`, `SecurityLocked`.
        :param str opposite_interface_id: The Interface ID of the router at the other end.
        :param str opposite_interface_owner_id: The AliCloud account ID of the owner of the router interface on the other end.
        :param str opposite_interface_spec: The opposite interface spec of the router on the other side. Valid Values: `Mini.2`, `Mini.5`, `Mini.5`, `Small.2`, `Small.5`, `Middle.1`, `Middle.2`, `Middle.5`, `Large.1`, `Large.2`, `Large.5`, `XLarge.1`, `Negative`.
        :param str opposite_interface_status: The opposite interface status of the router on the other side. Valid Values: `Idle`, `AcceptingConnecting`, `Connecting`, `Activating`, `Active`, `Modifying`, `Deactivating`, `Inactive`, `Deleting`.
        :param str opposite_region_id: The geographical ID of the location of the receiving end of the connection.
        :param str opposite_router_id: The id of the router at the other end.
        :param str opposite_router_type: The opposite router type of the router on the other side. Valid Values: `VRouter`, `VBR`.
        :param str opposite_vpc_instance_id: The opposite vpc instance id of the router on the other side.
        :param str payment_type: The payment methods for router interfaces. Valid Values: `PrePaid`, `PostPaid`.
        :param str reservation_active_time: The reservation active time of the resource.
        :param str reservation_bandwidth: The reservation bandwidth of the resource.
        :param str reservation_internet_charge_type: The reservation internet charge type of the resource.
        :param str reservation_order_type: The reservation order type of the resource.
        :param str role: The role of the router interface. Valid Values: `InitiatingSide`, `AcceptingSide`.
        :param str router_id: The router id associated with the router interface.
        :param str router_interface_id: The first ID of the resource.
        :param str router_interface_name: The name of the resource.
        :param str router_type: The type of router associated with the router interface. Valid Values: `VRouter`, `VBR`.
        :param str spec: The specification of the router interface. Valid Values: `Mini.2`, `Mini.5`, `Mini.5`, `Small.2`, `Small.5`, `Middle.1`, `Middle.2`, `Middle.5`, `Large.1`, `Large.2`, `Large.5`, `XLarge.1`, `Negative`.
        :param str status: The status of the resource. Valid Values: `Idle`, `AcceptingConnecting`, `Connecting`, `Activating`, `Active`, `Modifying`, `Deactivating`, `Inactive`, `Deleting`.
        :param str vpc_instance_id: The vpc instance id of the resource.
        """
        pulumi.set(__self__, "access_point_id", access_point_id)
        pulumi.set(__self__, "bandwidth", bandwidth)
        pulumi.set(__self__, "business_status", business_status)
        pulumi.set(__self__, "connected_time", connected_time)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "cross_border", cross_border)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "end_time", end_time)
        pulumi.set(__self__, "has_reservation_data", has_reservation_data)
        pulumi.set(__self__, "hc_rate", hc_rate)
        pulumi.set(__self__, "hc_threshold", hc_threshold)
        pulumi.set(__self__, "health_check_source_ip", health_check_source_ip)
        pulumi.set(__self__, "health_check_target_ip", health_check_target_ip)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "opposite_access_point_id", opposite_access_point_id)
        pulumi.set(__self__, "opposite_bandwidth", opposite_bandwidth)
        pulumi.set(__self__, "opposite_interface_business_status", opposite_interface_business_status)
        pulumi.set(__self__, "opposite_interface_id", opposite_interface_id)
        pulumi.set(__self__, "opposite_interface_owner_id", opposite_interface_owner_id)
        pulumi.set(__self__, "opposite_interface_spec", opposite_interface_spec)
        pulumi.set(__self__, "opposite_interface_status", opposite_interface_status)
        pulumi.set(__self__, "opposite_region_id", opposite_region_id)
        pulumi.set(__self__, "opposite_router_id", opposite_router_id)
        pulumi.set(__self__, "opposite_router_type", opposite_router_type)
        pulumi.set(__self__, "opposite_vpc_instance_id", opposite_vpc_instance_id)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "reservation_active_time", reservation_active_time)
        pulumi.set(__self__, "reservation_bandwidth", reservation_bandwidth)
        pulumi.set(__self__, "reservation_internet_charge_type", reservation_internet_charge_type)
        pulumi.set(__self__, "reservation_order_type", reservation_order_type)
        pulumi.set(__self__, "role", role)
        pulumi.set(__self__, "router_id", router_id)
        pulumi.set(__self__, "router_interface_id", router_interface_id)
        pulumi.set(__self__, "router_interface_name", router_interface_name)
        pulumi.set(__self__, "router_type", router_type)
        pulumi.set(__self__, "spec", spec)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "vpc_instance_id", vpc_instance_id)

    @property
    @pulumi.getter(name="accessPointId")
    def access_point_id(self) -> str:
        """
        The access point ID to which the VBR belongs.
        """
        return pulumi.get(self, "access_point_id")

    @property
    @pulumi.getter
    def bandwidth(self) -> int:
        """
        The bandwidth of the resource.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> str:
        """
        The businessStatus of the resource. Valid Values: `Normal`, `FinancialLocked`, `SecurityLocked`.
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="connectedTime")
    def connected_time(self) -> str:
        """
        The connected time of the resource.
        """
        return pulumi.get(self, "connected_time")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="crossBorder")
    def cross_border(self) -> bool:
        """
        The cross border of the resource.
        """
        return pulumi.get(self, "cross_border")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the router interface.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> str:
        """
        The end time of the resource.
        """
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter(name="hasReservationData")
    def has_reservation_data(self) -> str:
        """
        The has reservation data of the resource.
        """
        return pulumi.get(self, "has_reservation_data")

    @property
    @pulumi.getter(name="hcRate")
    def hc_rate(self) -> int:
        """
        The hc rate of the resource.
        """
        return pulumi.get(self, "hc_rate")

    @property
    @pulumi.getter(name="hcThreshold")
    def hc_threshold(self) -> str:
        """
        The hc threshold of the resource.
        """
        return pulumi.get(self, "hc_threshold")

    @property
    @pulumi.getter(name="healthCheckSourceIp")
    def health_check_source_ip(self) -> str:
        """
        The health check source IP address, must be an unused IP within the local VPC.
        """
        return pulumi.get(self, "health_check_source_ip")

    @property
    @pulumi.getter(name="healthCheckTargetIp")
    def health_check_target_ip(self) -> str:
        """
        The IP address for health screening purposes.
        """
        return pulumi.get(self, "health_check_target_ip")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="oppositeAccessPointId")
    def opposite_access_point_id(self) -> str:
        """
        The Access point ID to which the other end belongs.
        """
        return pulumi.get(self, "opposite_access_point_id")

    @property
    @pulumi.getter(name="oppositeBandwidth")
    def opposite_bandwidth(self) -> int:
        """
        The opposite bandwidth of the router on the other side.
        """
        return pulumi.get(self, "opposite_bandwidth")

    @property
    @pulumi.getter(name="oppositeInterfaceBusinessStatus")
    def opposite_interface_business_status(self) -> str:
        """
        The opposite interface business status of the router on the other side. Valid Values: `Normal`, `FinancialLocked`, `SecurityLocked`.
        """
        return pulumi.get(self, "opposite_interface_business_status")

    @property
    @pulumi.getter(name="oppositeInterfaceId")
    def opposite_interface_id(self) -> str:
        """
        The Interface ID of the router at the other end.
        """
        return pulumi.get(self, "opposite_interface_id")

    @property
    @pulumi.getter(name="oppositeInterfaceOwnerId")
    def opposite_interface_owner_id(self) -> str:
        """
        The AliCloud account ID of the owner of the router interface on the other end.
        """
        return pulumi.get(self, "opposite_interface_owner_id")

    @property
    @pulumi.getter(name="oppositeInterfaceSpec")
    def opposite_interface_spec(self) -> str:
        """
        The opposite interface spec of the router on the other side. Valid Values: `Mini.2`, `Mini.5`, `Mini.5`, `Small.2`, `Small.5`, `Middle.1`, `Middle.2`, `Middle.5`, `Large.1`, `Large.2`, `Large.5`, `XLarge.1`, `Negative`.
        """
        return pulumi.get(self, "opposite_interface_spec")

    @property
    @pulumi.getter(name="oppositeInterfaceStatus")
    def opposite_interface_status(self) -> str:
        """
        The opposite interface status of the router on the other side. Valid Values: `Idle`, `AcceptingConnecting`, `Connecting`, `Activating`, `Active`, `Modifying`, `Deactivating`, `Inactive`, `Deleting`.
        """
        return pulumi.get(self, "opposite_interface_status")

    @property
    @pulumi.getter(name="oppositeRegionId")
    def opposite_region_id(self) -> str:
        """
        The geographical ID of the location of the receiving end of the connection.
        """
        return pulumi.get(self, "opposite_region_id")

    @property
    @pulumi.getter(name="oppositeRouterId")
    def opposite_router_id(self) -> str:
        """
        The id of the router at the other end.
        """
        return pulumi.get(self, "opposite_router_id")

    @property
    @pulumi.getter(name="oppositeRouterType")
    def opposite_router_type(self) -> str:
        """
        The opposite router type of the router on the other side. Valid Values: `VRouter`, `VBR`.
        """
        return pulumi.get(self, "opposite_router_type")

    @property
    @pulumi.getter(name="oppositeVpcInstanceId")
    def opposite_vpc_instance_id(self) -> str:
        """
        The opposite vpc instance id of the router on the other side.
        """
        return pulumi.get(self, "opposite_vpc_instance_id")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> str:
        """
        The payment methods for router interfaces. Valid Values: `PrePaid`, `PostPaid`.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="reservationActiveTime")
    def reservation_active_time(self) -> str:
        """
        The reservation active time of the resource.
        """
        return pulumi.get(self, "reservation_active_time")

    @property
    @pulumi.getter(name="reservationBandwidth")
    def reservation_bandwidth(self) -> str:
        """
        The reservation bandwidth of the resource.
        """
        return pulumi.get(self, "reservation_bandwidth")

    @property
    @pulumi.getter(name="reservationInternetChargeType")
    def reservation_internet_charge_type(self) -> str:
        """
        The reservation internet charge type of the resource.
        """
        return pulumi.get(self, "reservation_internet_charge_type")

    @property
    @pulumi.getter(name="reservationOrderType")
    def reservation_order_type(self) -> str:
        """
        The reservation order type of the resource.
        """
        return pulumi.get(self, "reservation_order_type")

    @property
    @pulumi.getter
    def role(self) -> str:
        """
        The role of the router interface. Valid Values: `InitiatingSide`, `AcceptingSide`.
        """
        return pulumi.get(self, "role")

    @property
    @pulumi.getter(name="routerId")
    def router_id(self) -> str:
        """
        The router id associated with the router interface.
        """
        return pulumi.get(self, "router_id")

    @property
    @pulumi.getter(name="routerInterfaceId")
    def router_interface_id(self) -> str:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "router_interface_id")

    @property
    @pulumi.getter(name="routerInterfaceName")
    def router_interface_name(self) -> str:
        """
        The name of the resource.
        """
        return pulumi.get(self, "router_interface_name")

    @property
    @pulumi.getter(name="routerType")
    def router_type(self) -> str:
        """
        The type of router associated with the router interface. Valid Values: `VRouter`, `VBR`.
        """
        return pulumi.get(self, "router_type")

    @property
    @pulumi.getter
    def spec(self) -> str:
        """
        The specification of the router interface. Valid Values: `Mini.2`, `Mini.5`, `Mini.5`, `Small.2`, `Small.5`, `Middle.1`, `Middle.2`, `Middle.5`, `Large.1`, `Large.2`, `Large.5`, `XLarge.1`, `Negative`.
        """
        return pulumi.get(self, "spec")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the resource. Valid Values: `Idle`, `AcceptingConnecting`, `Connecting`, `Activating`, `Active`, `Modifying`, `Deactivating`, `Inactive`, `Deleting`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcInstanceId")
    def vpc_instance_id(self) -> str:
        """
        The vpc instance id of the resource.
        """
        return pulumi.get(self, "vpc_instance_id")


@pulumi.output_type
class GetVbrPconnAssociationsAssociationResult(dict):
    def __init__(__self__, *,
                 circuit_code: str,
                 enable_ipv6: bool,
                 id: str,
                 local_gateway_ip: str,
                 local_ipv6_gateway_ip: str,
                 peer_gateway_ip: str,
                 peer_ipv6_gateway_ip: str,
                 peering_ipv6_subnet_mask: str,
                 peering_subnet_mask: str,
                 physical_connection_id: str,
                 status: str,
                 vbr_id: str,
                 vlan_id: int):
        """
        :param str circuit_code: The circuit code provided by the operator for the physical connection.
        :param bool enable_ipv6: Whether IPv6 is enabled.
        :param str id: The ID of the Vbr Pconn Association.
        :param str local_gateway_ip: The Alibaba cloud IP address of the VBR instance.
        :param str local_ipv6_gateway_ip: The IPv6 address on the Alibaba Cloud side of the VBR instance.
        :param str peer_gateway_ip: The client IP address of the VBR instance.
        :param str peer_ipv6_gateway_ip: The IPv6 address of the client side of the VBR instance.
        :param str peering_ipv6_subnet_mask: The subnet mask of the Alibaba Cloud side and the client side of the VBR instance.Two IPv6 addresses must be in the same subnet.
        :param str peering_subnet_mask: The subnet mask of the Alibaba Cloud side and the client side of the VBR instance.The two IP addresses must be in the same subnet.
        :param str physical_connection_id: The ID of the leased line instance.
        :param str status: The status of the resource
        :param str vbr_id: The ID of the VBR instance.
        :param int vlan_id: VLAN ID of the VBR.
        """
        pulumi.set(__self__, "circuit_code", circuit_code)
        pulumi.set(__self__, "enable_ipv6", enable_ipv6)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "local_gateway_ip", local_gateway_ip)
        pulumi.set(__self__, "local_ipv6_gateway_ip", local_ipv6_gateway_ip)
        pulumi.set(__self__, "peer_gateway_ip", peer_gateway_ip)
        pulumi.set(__self__, "peer_ipv6_gateway_ip", peer_ipv6_gateway_ip)
        pulumi.set(__self__, "peering_ipv6_subnet_mask", peering_ipv6_subnet_mask)
        pulumi.set(__self__, "peering_subnet_mask", peering_subnet_mask)
        pulumi.set(__self__, "physical_connection_id", physical_connection_id)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "vbr_id", vbr_id)
        pulumi.set(__self__, "vlan_id", vlan_id)

    @property
    @pulumi.getter(name="circuitCode")
    def circuit_code(self) -> str:
        """
        The circuit code provided by the operator for the physical connection.
        """
        return pulumi.get(self, "circuit_code")

    @property
    @pulumi.getter(name="enableIpv6")
    def enable_ipv6(self) -> bool:
        """
        Whether IPv6 is enabled.
        """
        return pulumi.get(self, "enable_ipv6")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Vbr Pconn Association.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="localGatewayIp")
    def local_gateway_ip(self) -> str:
        """
        The Alibaba cloud IP address of the VBR instance.
        """
        return pulumi.get(self, "local_gateway_ip")

    @property
    @pulumi.getter(name="localIpv6GatewayIp")
    def local_ipv6_gateway_ip(self) -> str:
        """
        The IPv6 address on the Alibaba Cloud side of the VBR instance.
        """
        return pulumi.get(self, "local_ipv6_gateway_ip")

    @property
    @pulumi.getter(name="peerGatewayIp")
    def peer_gateway_ip(self) -> str:
        """
        The client IP address of the VBR instance.
        """
        return pulumi.get(self, "peer_gateway_ip")

    @property
    @pulumi.getter(name="peerIpv6GatewayIp")
    def peer_ipv6_gateway_ip(self) -> str:
        """
        The IPv6 address of the client side of the VBR instance.
        """
        return pulumi.get(self, "peer_ipv6_gateway_ip")

    @property
    @pulumi.getter(name="peeringIpv6SubnetMask")
    def peering_ipv6_subnet_mask(self) -> str:
        """
        The subnet mask of the Alibaba Cloud side and the client side of the VBR instance.Two IPv6 addresses must be in the same subnet.
        """
        return pulumi.get(self, "peering_ipv6_subnet_mask")

    @property
    @pulumi.getter(name="peeringSubnetMask")
    def peering_subnet_mask(self) -> str:
        """
        The subnet mask of the Alibaba Cloud side and the client side of the VBR instance.The two IP addresses must be in the same subnet.
        """
        return pulumi.get(self, "peering_subnet_mask")

    @property
    @pulumi.getter(name="physicalConnectionId")
    def physical_connection_id(self) -> str:
        """
        The ID of the leased line instance.
        """
        return pulumi.get(self, "physical_connection_id")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vbrId")
    def vbr_id(self) -> str:
        """
        The ID of the VBR instance.
        """
        return pulumi.get(self, "vbr_id")

    @property
    @pulumi.getter(name="vlanId")
    def vlan_id(self) -> int:
        """
        VLAN ID of the VBR.
        """
        return pulumi.get(self, "vlan_id")


@pulumi.output_type
class GetVirtualBorderRoutersFilterResult(dict):
    def __init__(__self__, *,
                 key: Optional[str] = None,
                 values: Optional[Sequence[str]] = None):
        """
        :param str key: The key of the field to filter by, as defined by
               [Alibaba Cloud API](https://www.alibabacloud.com/help/en/doc-detail/124791.htm).
        :param Sequence[str] values: Set of values that are accepted for the given field.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if values is not None:
            pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def key(self) -> Optional[str]:
        """
        The key of the field to filter by, as defined by
        [Alibaba Cloud API](https://www.alibabacloud.com/help/en/doc-detail/124791.htm).
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def values(self) -> Optional[Sequence[str]]:
        """
        Set of values that are accepted for the given field.
        """
        return pulumi.get(self, "values")


@pulumi.output_type
class GetVirtualBorderRoutersRouterResult(dict):
    def __init__(__self__, *,
                 access_point_id: str,
                 activation_time: str,
                 circuit_code: str,
                 cloud_box_instance_id: str,
                 create_time: str,
                 description: str,
                 detect_multiplier: int,
                 ecc_id: str,
                 enable_ipv6: bool,
                 id: str,
                 local_gateway_ip: str,
                 local_ipv6_gateway_ip: str,
                 min_rx_interval: int,
                 min_tx_interval: int,
                 payment_vbr_expire_time: str,
                 peer_gateway_ip: str,
                 peer_ipv6_gateway_ip: str,
                 peering_ipv6_subnet_mask: str,
                 peering_subnet_mask: str,
                 physical_connection_business_status: str,
                 physical_connection_id: str,
                 physical_connection_owner_uid: str,
                 physical_connection_status: str,
                 recovery_time: str,
                 route_table_id: str,
                 status: str,
                 termination_time: str,
                 type: str,
                 virtual_border_router_id: str,
                 virtual_border_router_name: str,
                 vlan_id: int,
                 vlan_interface_id: str):
        """
        :param str access_point_id: The physical leased line access point ID.
        :param str activation_time: The first activation time of VBR.
        :param str circuit_code: Operators for physical connection circuit provided coding.
        :param str cloud_box_instance_id: Box Instance Id.
        :param str create_time: The representative of the creation time resources attribute field.
        :param str description: The description of VBR. Length is from 2 to 256 characters, must start with a letter or the Chinese at the beginning, but not at the http:// Or https:// at the beginning.
        :param int detect_multiplier: Detection time multiplier that recipient allows the sender to send a message of the maximum allowable connections for the number of packets, used to detect whether the link normal. Value: 3~10.
        :param str ecc_id: High Speed Migration Service Instance Id.
        :param bool enable_ipv6: Whether to Enable IPv6.
        :param str id: The ID of the Virtual Border Router.
        :param str local_gateway_ip: Alibaba Cloud-Connected IPv4 address.
        :param str local_ipv6_gateway_ip: Alibaba Cloud-Connected IPv6 Address.
        :param int min_rx_interval: Configure BFD packet reception interval of values include: 200~1000, unit: ms.
        :param int min_tx_interval: Configure BFD packet transmission interval maximum value: 200~1000, unit: ms.
        :param str payment_vbr_expire_time: The Billing of the Extended Time.
        :param str peer_gateway_ip: The Client-Side Interconnection IPv4 Address.
        :param str peer_ipv6_gateway_ip: The Client-Side Interconnection IPv6 Address.
        :param str peering_ipv6_subnet_mask: Alibaba Cloud-Connected IPv6 with Client-Side Interconnection IPv6 of Subnet Mask.
        :param str peering_subnet_mask: Alibaba Cloud-Connected IPv4 and Client-Side Interconnection IPv4 of Subnet Mask.
        :param str physical_connection_business_status: Physical Private Line Service Status Value Normal: Normal, financiallocked: If You Lock.
        :param str physical_connection_id: The ID of the Physical Connection to Which the ID.
        :param str physical_connection_owner_uid: Physical Private Line Where the Account ID.
        :param str physical_connection_status: Physical Private Line State.
        :param str recovery_time: The Last from a Terminated State to the Active State of the Time.
        :param str route_table_id: Route Table ID.
        :param str status: The VBR state.
        :param str termination_time: The Most Recent Was Aborted by the Time.
        :param str type: VBR Type.
        :param str virtual_border_router_id: The VBR ID.
        :param str virtual_border_router_name: The name of VBR. Length is from 2 to 128 characters, must start with a letter or the Chinese at the beginning can contain numbers, the underscore character (_) and dash (-). But do not start with http:// or https:// at the beginning.
        :param int vlan_id: The VLAN ID of the VBR. Value range: 0~2999.
        :param str vlan_interface_id: The ID of the Router Interface.
        """
        pulumi.set(__self__, "access_point_id", access_point_id)
        pulumi.set(__self__, "activation_time", activation_time)
        pulumi.set(__self__, "circuit_code", circuit_code)
        pulumi.set(__self__, "cloud_box_instance_id", cloud_box_instance_id)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "detect_multiplier", detect_multiplier)
        pulumi.set(__self__, "ecc_id", ecc_id)
        pulumi.set(__self__, "enable_ipv6", enable_ipv6)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "local_gateway_ip", local_gateway_ip)
        pulumi.set(__self__, "local_ipv6_gateway_ip", local_ipv6_gateway_ip)
        pulumi.set(__self__, "min_rx_interval", min_rx_interval)
        pulumi.set(__self__, "min_tx_interval", min_tx_interval)
        pulumi.set(__self__, "payment_vbr_expire_time", payment_vbr_expire_time)
        pulumi.set(__self__, "peer_gateway_ip", peer_gateway_ip)
        pulumi.set(__self__, "peer_ipv6_gateway_ip", peer_ipv6_gateway_ip)
        pulumi.set(__self__, "peering_ipv6_subnet_mask", peering_ipv6_subnet_mask)
        pulumi.set(__self__, "peering_subnet_mask", peering_subnet_mask)
        pulumi.set(__self__, "physical_connection_business_status", physical_connection_business_status)
        pulumi.set(__self__, "physical_connection_id", physical_connection_id)
        pulumi.set(__self__, "physical_connection_owner_uid", physical_connection_owner_uid)
        pulumi.set(__self__, "physical_connection_status", physical_connection_status)
        pulumi.set(__self__, "recovery_time", recovery_time)
        pulumi.set(__self__, "route_table_id", route_table_id)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "termination_time", termination_time)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "virtual_border_router_id", virtual_border_router_id)
        pulumi.set(__self__, "virtual_border_router_name", virtual_border_router_name)
        pulumi.set(__self__, "vlan_id", vlan_id)
        pulumi.set(__self__, "vlan_interface_id", vlan_interface_id)

    @property
    @pulumi.getter(name="accessPointId")
    def access_point_id(self) -> str:
        """
        The physical leased line access point ID.
        """
        return pulumi.get(self, "access_point_id")

    @property
    @pulumi.getter(name="activationTime")
    def activation_time(self) -> str:
        """
        The first activation time of VBR.
        """
        return pulumi.get(self, "activation_time")

    @property
    @pulumi.getter(name="circuitCode")
    def circuit_code(self) -> str:
        """
        Operators for physical connection circuit provided coding.
        """
        return pulumi.get(self, "circuit_code")

    @property
    @pulumi.getter(name="cloudBoxInstanceId")
    def cloud_box_instance_id(self) -> str:
        """
        Box Instance Id.
        """
        return pulumi.get(self, "cloud_box_instance_id")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The representative of the creation time resources attribute field.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of VBR. Length is from 2 to 256 characters, must start with a letter or the Chinese at the beginning, but not at the http:// Or https:// at the beginning.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="detectMultiplier")
    def detect_multiplier(self) -> int:
        """
        Detection time multiplier that recipient allows the sender to send a message of the maximum allowable connections for the number of packets, used to detect whether the link normal. Value: 3~10.
        """
        return pulumi.get(self, "detect_multiplier")

    @property
    @pulumi.getter(name="eccId")
    def ecc_id(self) -> str:
        """
        High Speed Migration Service Instance Id.
        """
        return pulumi.get(self, "ecc_id")

    @property
    @pulumi.getter(name="enableIpv6")
    def enable_ipv6(self) -> bool:
        """
        Whether to Enable IPv6.
        """
        return pulumi.get(self, "enable_ipv6")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Virtual Border Router.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="localGatewayIp")
    def local_gateway_ip(self) -> str:
        """
        Alibaba Cloud-Connected IPv4 address.
        """
        return pulumi.get(self, "local_gateway_ip")

    @property
    @pulumi.getter(name="localIpv6GatewayIp")
    def local_ipv6_gateway_ip(self) -> str:
        """
        Alibaba Cloud-Connected IPv6 Address.
        """
        return pulumi.get(self, "local_ipv6_gateway_ip")

    @property
    @pulumi.getter(name="minRxInterval")
    def min_rx_interval(self) -> int:
        """
        Configure BFD packet reception interval of values include: 200~1000, unit: ms.
        """
        return pulumi.get(self, "min_rx_interval")

    @property
    @pulumi.getter(name="minTxInterval")
    def min_tx_interval(self) -> int:
        """
        Configure BFD packet transmission interval maximum value: 200~1000, unit: ms.
        """
        return pulumi.get(self, "min_tx_interval")

    @property
    @pulumi.getter(name="paymentVbrExpireTime")
    def payment_vbr_expire_time(self) -> str:
        """
        The Billing of the Extended Time.
        """
        return pulumi.get(self, "payment_vbr_expire_time")

    @property
    @pulumi.getter(name="peerGatewayIp")
    def peer_gateway_ip(self) -> str:
        """
        The Client-Side Interconnection IPv4 Address.
        """
        return pulumi.get(self, "peer_gateway_ip")

    @property
    @pulumi.getter(name="peerIpv6GatewayIp")
    def peer_ipv6_gateway_ip(self) -> str:
        """
        The Client-Side Interconnection IPv6 Address.
        """
        return pulumi.get(self, "peer_ipv6_gateway_ip")

    @property
    @pulumi.getter(name="peeringIpv6SubnetMask")
    def peering_ipv6_subnet_mask(self) -> str:
        """
        Alibaba Cloud-Connected IPv6 with Client-Side Interconnection IPv6 of Subnet Mask.
        """
        return pulumi.get(self, "peering_ipv6_subnet_mask")

    @property
    @pulumi.getter(name="peeringSubnetMask")
    def peering_subnet_mask(self) -> str:
        """
        Alibaba Cloud-Connected IPv4 and Client-Side Interconnection IPv4 of Subnet Mask.
        """
        return pulumi.get(self, "peering_subnet_mask")

    @property
    @pulumi.getter(name="physicalConnectionBusinessStatus")
    def physical_connection_business_status(self) -> str:
        """
        Physical Private Line Service Status Value Normal: Normal, financiallocked: If You Lock.
        """
        return pulumi.get(self, "physical_connection_business_status")

    @property
    @pulumi.getter(name="physicalConnectionId")
    def physical_connection_id(self) -> str:
        """
        The ID of the Physical Connection to Which the ID.
        """
        return pulumi.get(self, "physical_connection_id")

    @property
    @pulumi.getter(name="physicalConnectionOwnerUid")
    def physical_connection_owner_uid(self) -> str:
        """
        Physical Private Line Where the Account ID.
        """
        return pulumi.get(self, "physical_connection_owner_uid")

    @property
    @pulumi.getter(name="physicalConnectionStatus")
    def physical_connection_status(self) -> str:
        """
        Physical Private Line State.
        """
        return pulumi.get(self, "physical_connection_status")

    @property
    @pulumi.getter(name="recoveryTime")
    def recovery_time(self) -> str:
        """
        The Last from a Terminated State to the Active State of the Time.
        """
        return pulumi.get(self, "recovery_time")

    @property
    @pulumi.getter(name="routeTableId")
    def route_table_id(self) -> str:
        """
        Route Table ID.
        """
        return pulumi.get(self, "route_table_id")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The VBR state.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="terminationTime")
    def termination_time(self) -> str:
        """
        The Most Recent Was Aborted by the Time.
        """
        return pulumi.get(self, "termination_time")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        VBR Type.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="virtualBorderRouterId")
    def virtual_border_router_id(self) -> str:
        """
        The VBR ID.
        """
        return pulumi.get(self, "virtual_border_router_id")

    @property
    @pulumi.getter(name="virtualBorderRouterName")
    def virtual_border_router_name(self) -> str:
        """
        The name of VBR. Length is from 2 to 128 characters, must start with a letter or the Chinese at the beginning can contain numbers, the underscore character (_) and dash (-). But do not start with http:// or https:// at the beginning.
        """
        return pulumi.get(self, "virtual_border_router_name")

    @property
    @pulumi.getter(name="vlanId")
    def vlan_id(self) -> int:
        """
        The VLAN ID of the VBR. Value range: 0~2999.
        """
        return pulumi.get(self, "vlan_id")

    @property
    @pulumi.getter(name="vlanInterfaceId")
    def vlan_interface_id(self) -> str:
        """
        The ID of the Router Interface.
        """
        return pulumi.get(self, "vlan_interface_id")


@pulumi.output_type
class GetVirtualPhysicalConnectionsConnectionResult(dict):
    def __init__(__self__, *,
                 access_point_id: str,
                 ad_location: str,
                 bandwidth: str,
                 business_status: str,
                 circuit_code: str,
                 create_time: str,
                 description: str,
                 enabled_time: str,
                 end_time: str,
                 expect_spec: str,
                 id: str,
                 line_operator: str,
                 loa_status: str,
                 order_mode: str,
                 parent_physical_connection_ali_uid: str,
                 parent_physical_connection_id: str,
                 peer_location: str,
                 port_number: str,
                 port_type: str,
                 redundant_physical_connection_id: str,
                 resource_group_id: str,
                 spec: str,
                 status: str,
                 virtual_physical_connection_id: str,
                 virtual_physical_connection_name: str,
                 virtual_physical_connection_status: str,
                 vlan_id: int,
                 vpconn_ali_uid: str):
        """
        :param str access_point_id: The ID of the access point of the physical connection.
        :param str ad_location: The physical location where the physical connection access device is located.
        :param str bandwidth: The bandwidth of the physical connection. Unit: Mbps.
        :param str business_status: The commercial status of the physical line. Value:
               - **Normal**: activated.
               - **Financialized**: Arrears locked.
               - **SecurityLocked**: locked for security reasons.
        :param str circuit_code: The circuit code provided by the operator for the physical connection.
        :param str create_time: The creation time of the resource
        :param str description: The description of the physical connection.
        :param str enabled_time: The opening time of the physical connection.
        :param str end_time: The expiration time of the shared line.Time is expressed according to ISO8601 standard and UTC time is used. The format is: YYYY-MM-DDThh:mm:ssZ.
        :param str expect_spec: The estimated bandwidth value of the shared line. The expected bandwidth value will not take effect until the payment is completed.Unit: **M** indicates Mbps,**G** indicates Gbps.
        :param str id: The ID of the Virtual Physical Connection.
        :param str line_operator: Operators that provide access to physical lines. Value:-**CT**: China Telecom.-**CU**: China Unicom.-**CM**: China Mobile.-**CO**: China Other.-**Equinix**:Equinix.-**Other**: Other abroad.
        :param str loa_status: The state of LOA. Value:-**Applying**:LOA application.-**Accept**:LOA application passed.-**Available**:LOA is Available.-**Rejected**:LOA application Rejected.-**Completing**: The dedicated line is under construction.-**Complete**: The construction of the dedicated line is completed.-**Deleted**:LOA has been Deleted.
        :param str order_mode: The payment method of shared dedicated line. Value:-**PayByPhysicalConnectionOwner**: indicates that the owner of the physical line associated with the shared line pays.-**PayByVirtualPhysicalConnectionOwner**: indicates that the owner of the shared line pays.
        :param str parent_physical_connection_ali_uid: The ID of the Alibaba Cloud account (primary account) to which the physical connection belongs.
        :param str parent_physical_connection_id: The ID of the instance of the physical connection.
        :param str peer_location: The geographic location of the local data center.
        :param str port_number: The port number of the physical connection device.
        :param str port_type: Physical connection port type. Value:-**100Base-T**: 100 megabytes port.-**1000Base-T**: Gigabit port.-**1000Base-LX**: Gigabit single mode optical port (10km).-**10GBase-T**: 10 Gigabit port.-**10GBase-LR**: 10 Gigabit single mode optical port (10km).-**40GBase-LR**: 40 megabytes single-mode optical port.-**100GBase-LR**: 100,000 megabytes single-mode optical port.
        :param str redundant_physical_connection_id: The ID of the redundant physical connection.
        :param str resource_group_id: The resource group id
        :param str spec: The bandwidth value of the shared line.Unit: **M** indicates Mbps,**G** indicates Gbps.
        :param str status: The status of the resource
        :param str virtual_physical_connection_id: The ID of the hosted connection
        :param str virtual_physical_connection_name: The name of the physical connection.
        :param str virtual_physical_connection_status: The business status of the shared line. Value:
               - **Confirmed**: The shared line has been Confirmed to receive.
               - **UnConfirmed**: The shared line has not been confirmed to be received.
               - **Deleted**: The shared line has been Deleted.
        :param int vlan_id: The VLAN ID of the shared leased line.
        :param str vpconn_ali_uid: The ID of the Alibaba Cloud account (primary account) of the owner of the shared line.
        """
        pulumi.set(__self__, "access_point_id", access_point_id)
        pulumi.set(__self__, "ad_location", ad_location)
        pulumi.set(__self__, "bandwidth", bandwidth)
        pulumi.set(__self__, "business_status", business_status)
        pulumi.set(__self__, "circuit_code", circuit_code)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "enabled_time", enabled_time)
        pulumi.set(__self__, "end_time", end_time)
        pulumi.set(__self__, "expect_spec", expect_spec)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "line_operator", line_operator)
        pulumi.set(__self__, "loa_status", loa_status)
        pulumi.set(__self__, "order_mode", order_mode)
        pulumi.set(__self__, "parent_physical_connection_ali_uid", parent_physical_connection_ali_uid)
        pulumi.set(__self__, "parent_physical_connection_id", parent_physical_connection_id)
        pulumi.set(__self__, "peer_location", peer_location)
        pulumi.set(__self__, "port_number", port_number)
        pulumi.set(__self__, "port_type", port_type)
        pulumi.set(__self__, "redundant_physical_connection_id", redundant_physical_connection_id)
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        pulumi.set(__self__, "spec", spec)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "virtual_physical_connection_id", virtual_physical_connection_id)
        pulumi.set(__self__, "virtual_physical_connection_name", virtual_physical_connection_name)
        pulumi.set(__self__, "virtual_physical_connection_status", virtual_physical_connection_status)
        pulumi.set(__self__, "vlan_id", vlan_id)
        pulumi.set(__self__, "vpconn_ali_uid", vpconn_ali_uid)

    @property
    @pulumi.getter(name="accessPointId")
    def access_point_id(self) -> str:
        """
        The ID of the access point of the physical connection.
        """
        return pulumi.get(self, "access_point_id")

    @property
    @pulumi.getter(name="adLocation")
    def ad_location(self) -> str:
        """
        The physical location where the physical connection access device is located.
        """
        return pulumi.get(self, "ad_location")

    @property
    @pulumi.getter
    def bandwidth(self) -> str:
        """
        The bandwidth of the physical connection. Unit: Mbps.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> str:
        """
        The commercial status of the physical line. Value:
        - **Normal**: activated.
        - **Financialized**: Arrears locked.
        - **SecurityLocked**: locked for security reasons.
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="circuitCode")
    def circuit_code(self) -> str:
        """
        The circuit code provided by the operator for the physical connection.
        """
        return pulumi.get(self, "circuit_code")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the physical connection.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enabledTime")
    def enabled_time(self) -> str:
        """
        The opening time of the physical connection.
        """
        return pulumi.get(self, "enabled_time")

    @property
    @pulumi.getter(name="endTime")
    def end_time(self) -> str:
        """
        The expiration time of the shared line.Time is expressed according to ISO8601 standard and UTC time is used. The format is: YYYY-MM-DDThh:mm:ssZ.
        """
        return pulumi.get(self, "end_time")

    @property
    @pulumi.getter(name="expectSpec")
    def expect_spec(self) -> str:
        """
        The estimated bandwidth value of the shared line. The expected bandwidth value will not take effect until the payment is completed.Unit: **M** indicates Mbps,**G** indicates Gbps.
        """
        return pulumi.get(self, "expect_spec")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Virtual Physical Connection.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lineOperator")
    def line_operator(self) -> str:
        """
        Operators that provide access to physical lines. Value:-**CT**: China Telecom.-**CU**: China Unicom.-**CM**: China Mobile.-**CO**: China Other.-**Equinix**:Equinix.-**Other**: Other abroad.
        """
        return pulumi.get(self, "line_operator")

    @property
    @pulumi.getter(name="loaStatus")
    def loa_status(self) -> str:
        """
        The state of LOA. Value:-**Applying**:LOA application.-**Accept**:LOA application passed.-**Available**:LOA is Available.-**Rejected**:LOA application Rejected.-**Completing**: The dedicated line is under construction.-**Complete**: The construction of the dedicated line is completed.-**Deleted**:LOA has been Deleted.
        """
        return pulumi.get(self, "loa_status")

    @property
    @pulumi.getter(name="orderMode")
    def order_mode(self) -> str:
        """
        The payment method of shared dedicated line. Value:-**PayByPhysicalConnectionOwner**: indicates that the owner of the physical line associated with the shared line pays.-**PayByVirtualPhysicalConnectionOwner**: indicates that the owner of the shared line pays.
        """
        return pulumi.get(self, "order_mode")

    @property
    @pulumi.getter(name="parentPhysicalConnectionAliUid")
    def parent_physical_connection_ali_uid(self) -> str:
        """
        The ID of the Alibaba Cloud account (primary account) to which the physical connection belongs.
        """
        return pulumi.get(self, "parent_physical_connection_ali_uid")

    @property
    @pulumi.getter(name="parentPhysicalConnectionId")
    def parent_physical_connection_id(self) -> str:
        """
        The ID of the instance of the physical connection.
        """
        return pulumi.get(self, "parent_physical_connection_id")

    @property
    @pulumi.getter(name="peerLocation")
    def peer_location(self) -> str:
        """
        The geographic location of the local data center.
        """
        return pulumi.get(self, "peer_location")

    @property
    @pulumi.getter(name="portNumber")
    def port_number(self) -> str:
        """
        The port number of the physical connection device.
        """
        return pulumi.get(self, "port_number")

    @property
    @pulumi.getter(name="portType")
    def port_type(self) -> str:
        """
        Physical connection port type. Value:-**100Base-T**: 100 megabytes port.-**1000Base-T**: Gigabit port.-**1000Base-LX**: Gigabit single mode optical port (10km).-**10GBase-T**: 10 Gigabit port.-**10GBase-LR**: 10 Gigabit single mode optical port (10km).-**40GBase-LR**: 40 megabytes single-mode optical port.-**100GBase-LR**: 100,000 megabytes single-mode optical port.
        """
        return pulumi.get(self, "port_type")

    @property
    @pulumi.getter(name="redundantPhysicalConnectionId")
    def redundant_physical_connection_id(self) -> str:
        """
        The ID of the redundant physical connection.
        """
        return pulumi.get(self, "redundant_physical_connection_id")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> str:
        """
        The resource group id
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def spec(self) -> str:
        """
        The bandwidth value of the shared line.Unit: **M** indicates Mbps,**G** indicates Gbps.
        """
        return pulumi.get(self, "spec")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="virtualPhysicalConnectionId")
    def virtual_physical_connection_id(self) -> str:
        """
        The ID of the hosted connection
        """
        return pulumi.get(self, "virtual_physical_connection_id")

    @property
    @pulumi.getter(name="virtualPhysicalConnectionName")
    def virtual_physical_connection_name(self) -> str:
        """
        The name of the physical connection.
        """
        return pulumi.get(self, "virtual_physical_connection_name")

    @property
    @pulumi.getter(name="virtualPhysicalConnectionStatus")
    def virtual_physical_connection_status(self) -> str:
        """
        The business status of the shared line. Value:
        - **Confirmed**: The shared line has been Confirmed to receive.
        - **UnConfirmed**: The shared line has not been confirmed to be received.
        - **Deleted**: The shared line has been Deleted.
        """
        return pulumi.get(self, "virtual_physical_connection_status")

    @property
    @pulumi.getter(name="vlanId")
    def vlan_id(self) -> int:
        """
        The VLAN ID of the shared leased line.
        """
        return pulumi.get(self, "vlan_id")

    @property
    @pulumi.getter(name="vpconnAliUid")
    def vpconn_ali_uid(self) -> str:
        """
        The ID of the Alibaba Cloud account (primary account) of the owner of the shared line.
        """
        return pulumi.get(self, "vpconn_ali_uid")


